This repository contains a python package used for running the
Selenium tests for `wed <https://github.com/mangalam-research/wed>`_.

Use 0.20.0 for wed 0.29.0 onwards. 0.19 only works with earlier
versions.
